References
############

.. [deJong1992]
    S. de Jong, H.A.L. Kiers,
    "Principal covariates regression: Part I. Theory",
    Chemom. intell. lab. syst. 14 (1992) 155-164
    https://doi.org/10.1016/0169-7439(92)80100-I

.. [Imbalzano2018]
    Giulio Imbalzano,  Andrea Anelli,  Daniele Giofré, Sinja Klees,  Jörg Behler, and  Michele Ceriotti,
    “Automatic selection of atomic fingerprints and reference configurations for machine-learning potentials.”
    The Journal of chemical physics 148 24 (2018): 241730.
    https://aip.scitation.org/doi/10.1063/1.5024611.

.. [Ceriotti2019]
    Michele Ceriotti, Lyndon Emsley, Federico Paruzzo, Albert Hofstetter, Félix Musil, Sandip De, Edgar A. Engel, and Andrea Anelli.
    "Chemical Shifts in Molecular Solids by Machine Learning Datasets",
    Materials Cloud Archive 2019.0023/v2 (2019),
    https://doi.org/10.24435/materialscloud:2019.0023/v2.

.. [Helfrecht2020]
    Benjamin A Helfrecht, Rose K Cersonsky, Guillaume Fraux, and Michele Ceriotti,
    "Structure-property maps with Kernel principal covariates regression."
    2020 Mach. Learn.: Sci. Technol. 1 045021.
    https://iopscience.iop.org/article/10.1088/2632-2153/aba9ef.

.. [Pozdnyakov2020]
    Pozdnyakov, S. N., Willatt, M. J., Bartók, A. P., Ortner, C., Csányi, G., & Ceriotti, M. (2020).
    "Incompleteness of Atomic Structure Representations."
    Physical Review Letters, 125(16).
    https://doi.org/10.1103/physrevlett.125.166001

.. [Goscinski2021]
    Alexander Goscinski, Guillaume Fraux, Giulio Imbalzano, and Michele Ceriotti,
    "The role of feature space in atomistic learning."
    2021 Mach. Learn.: Sci. Technol. 2 025028.
    https://iopscience.iop.org/article/10.1088/2632-2153/abdaf7.

.. [Cersonsky2021]
    Rose K Cersonsky, Benjamin A Helfrecht, Edgar A. Engel, Sergei Kliavinek, and Michele Ceriotti,
    "Improving Sample and Feature Selection with Principal Covariates Regression"
    2021 Mach. Learn.: Sci. Technol. 2 035038.
    https://iopscience.iop.org/article/10.1088/2632-2153/abfe7c.
